summaryrefslogtreecommitdiffstats
path: root/ksirc/puke/controller.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksirc/puke/controller.h')
-rw-r--r--ksirc/puke/controller.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ksirc/puke/controller.h b/ksirc/puke/controller.h
index 5d22cef3..92c8be98 100644
--- a/ksirc/puke/controller.h
+++ b/ksirc/puke/controller.h
@@ -82,7 +82,7 @@ class PukeController : public PObject
Q_OBJECT
TQ_OBJECT
public:
- PukeController(TQString socket = "", TQObject *tqparent=0, const char *name=0);
+ PukeController(TQString socket = "", TQObject *parent=0, const char *name=0);
virtual ~PukeController();
bool running;
@@ -169,7 +169,7 @@ private:
/**
* Create new Widget, returns new iWinId for it.
* Takes server fd and tqparent winid, and type as arguments
*/
widgetId createWidget(widgetId wI, PukeMessage *pm);
@@ -169,7 +169,7 @@ private:
/**
* Create new Widget, returns new iWinId for it.
- * Takes server fd and tqparent winid, and type as arguments
+ * Takes server fd and parent winid, and type as arguments
*/
widgetId createWidget(widgetId wI, PukeMessage *pm);